"""
Epidemiology_diagnostic

Compute diagnostic test performance metrics from a 2x2 contingency table (TP, FP, TN, FN). Return...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def Epidemiology_diagnostic(
    operation: str,
    tp: int,
    fp: int,
    tn: int,
    fn: int,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Compute diagnostic test performance metrics from a 2x2 contingency table (TP, FP, TN, FN). Return...

    Parameters
    ----------
    operation : str
        Operation type
    tp : int
        True positives (disease+, test+)
    fp : int
        False positives (disease-, test+)
    tn : int
        True negatives (disease-, test-)
    fn : int
        False negatives (disease+, test-)
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    # Strip None values so optional parameters don't trigger schema validation errors
    _args = {
        k: v
        for k, v in {
            "operation": operation,
            "tp": tp,
            "fp": fp,
            "tn": tn,
            "fn": fn,
        }.items()
        if v is not None
    }
    return get_shared_client().run_one_function(
        {
            "name": "Epidemiology_diagnostic",
            "arguments": _args,
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["Epidemiology_diagnostic"]
